@@ -3,7 +3,7 @@
 use 5.014002;
 use warnings;
 
-our $VERSION = "0.09 - 20240118";
+our $VERSION = "0.10 - 20240428";
 our $CMD = $0 =~ s{.*/}{}r;
 
 sub usage {
@@ -13,8 +13,9 @@ sub usage {
     say "    -m    --minimum      Report based on minimum (default recommended)";
     say "    -j F  --json=F       Use downloaded JSON instead of fetching";
     say "    -p    --perl         Report CVE's on required perl (default OFF)";
+    say "    -c    --corelist     Replace 0 versions w*ith CORE version";
     say "    -v[#] --verbose[=#]  Set verbosity level";
-    say "    -J F  --json-out=F   Output in JSON file F";
+    say "    -J F  --json-out=F   Output in JSON file F (- = STDOUT)";
     say "";
     say "For CVE's in the perl core, please use --perl and/or CPAN::Audit";
     say "Documentation should still be written";
@@ -23,6 +24,7 @@ sub usage {
 
 use Test::CVE;
 use JSON::MaybeXS;
+use Module::CoreList;
 use Cwd          qw( getcwd abs_path);
 use Getopt::Long qw(:config bundling noignorecase);
 GetOptions (
@@ -35,6 +37,7 @@ GetOptions (
     "J|json-out=s"	=> \ my $opt_J,
 
     "p|perl!"		=> \ my $opt_p,
+    "c|cl|corelist!"	=> \ my $opt_c,
 
     "v|verbose:1"	=> \(my $opt_v = 0),
     ) or usage (1);
@@ -46,6 +49,7 @@ foreach my $module (@ARGV) {
     my $cve = Test::CVE->new (
 	deps    => $opt_d,
 	perl    => $opt_p // 0,
+	core    => $opt_c // 0,
 	minimum => $opt_m,
 	cpansa  => $opt_j,
 	verbose => $opt_v,
@@ -98,7 +102,12 @@ foreach my $module (@ARGV) {
 
 chdir $tld;
 if ($opt_J) {
-    open my $fh, ">:encoding(utf-8)", $opt_J or die "$opt_J: $!\n";
-    say $fh encode_json (\%rpt);
-    close $fh;
+    if ($opt_J eq "-") {
+	say     encode_json (\%rpt);
+	}
+    else {
+	open my $fh, ">:encoding(utf-8)", $opt_J or die "$opt_J: $!\n";
+	say $fh encode_json (\%rpt);
+	close $fh;
+	}
     }
